-- ScalePTO
-- This is the specialization for scaling PTOs
--
-- Copyright (C) GIANTS Software GmbH, Confidential, All Rights Reserved.

ScalePTO = {};

function ScalePTO.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Cylindered, specializations);
end;

function ScalePTO:load(savegame)
    self.ptoAttachNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.scalePTO#attachNode"));
    self.ptoDetachNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.scalePTO#detachNode"));
    self.ptoAttachPos = Utils.getVectorNFromString(getXMLString(xmlFile, "vehicle.ScalePTO#attachPos"), 3);
end;

function ScalePTO:postLoad(xmlFile)
    ScalePTO.onDetach(self);
end;

function ScalePTO:delete()
    ScalePTO.onDetach(self);
end;

function ScalePTO:mouseEvent(posX, posY, isDown, isUp, button)
end;

function ScalePTO:keyEvent(unicode, sym, modifier, isDown)
end;

function ScalePTO:update(dt)
end;

function ScalePTO:updateTick(dt)
end;

function ScalePTO:onAttach(attacherVehicle, jointDescIndex)
    local jointDesc = attacherVehicle.attacherJoints[jointDescIndex];
    if jointDesc ~= nil and jointDesc.ptoOutput ~= nil and jointDesc.ptoOutput.node ~= nil then
        local linkNode = jointDesc.ptoOutput.node;
        link(linkNode, self.ptoAttachNode);
        setTranslation(self.ptoAttachNode, unpack(self.ptoAttachPos));
        setRotation(self.ptoAttachNode, math.rad(180), 0, 0);
    end;
end;

function ScalePTO:onDetach(attacherVehicle, jointDescIndex)
    link(self.ptoDetachNode, self.ptoAttachNode);
    setTranslation(self.ptoAttachNode, 0, 0, 0);
    setRotation(self.ptoAttachNode, 0, 0, 0);
    for _, part in pairs(self.activeDirtyMovingParts) do
        Cylindered.updateMovingPart(self, part, false);
    end
end;

function ScalePTO:draw()
end;